@@ -1,15 +1,8 @@
-#' @include ValidCorrGpois.R
-#' @include CorrNNGpois.R
-#' @importFrom corpcor is.positive.definite
-#' @importFrom Matrix nearPD
-NULL
-
-
 #' Computes Intermediate Correlation Matrix
 #'
 #' \code{CmatStarGpois} computes an intermediate correlation matrix that will be used to obtain
 #' the target correlation matrix using the inverse CDF transformation method in \code{GenMVGpois}.
-#' If the intermediate correlation martrix is not positive definite, the nearest positive definite
+#' If the intermediate correlation matrix is not positive definite, the nearest positive definite
 #' matrix is used.
 #'
 #' @param corMat target correlation matrix.
@@ -19,7 +12,7 @@ NULL
 #'  of the vector is at least two. All lambda values have to be less than 1.
 #'  For lambda < 0, lambda must be greater than or equal to -theta/4.
 #' @param verbose logical variable that determines whether to display the traces. Default is set to TRUE.
-#' @return intermediate correlation matrix.
+#' @return Intermediate correlation matrix.
 #' @examples
 #' \donttest{
 #'  lambda.vec = c(-0.2, 0.2, -0.3)
@@ -40,13 +33,13 @@ CmatStarGpois = function(corMat, theta.vec, lambda.vec, verbose = TRUE) {
   if (ValidCorrGpois(corMat, theta.vec, lambda.vec, verbose)) {
     corMat.star = diag(nrow(corMat))
     # lower matrix index
-    g <- expand.grid(row = 1:nrow(corMat), col = 1:ncol(corMat))
-    g.lower.tri <- g[lower.tri(corMat, diag = TRUE),]
-    corMat.lower.index <- g.lower.tri[-which(g.lower.tri[,1]==g.lower.tri[,2]),]
+    g = expand.grid(row = 1:nrow(corMat), col = 1:ncol(corMat))
+    g.lower.tri = g[lower.tri(corMat, diag = TRUE),]
+    corMat.lower.index = g.lower.tri[-which(g.lower.tri[,1]==g.lower.tri[,2]),]
     for (i in 1:nrow(corMat.lower.index)) {
-      i.temp <- corMat.lower.index[i,1]
-      j.temp <- corMat.lower.index[i,2]
-      corMat.star[i.temp,j.temp] <- CorrNNGpois(c(theta.vec[i.temp], theta.vec[j.temp]),
+      i.temp = corMat.lower.index[i,1]
+      j.temp = corMat.lower.index[i,2]
+      corMat.star[i.temp,j.temp] = CorrNNGpois(c(theta.vec[i.temp], theta.vec[j.temp]),
                                                 c(lambda.vec[i.temp], lambda.vec[j.temp]),
                                                 corMat[i.temp,j.temp])
       if (verbose == TRUE) {
@@ -54,13 +47,13 @@ CmatStarGpois = function(corMat, theta.vec, lambda.vec, verbose = TRUE) {
       }
     }
     # upper matrix index
-    g.upper.tri <- g[upper.tri(corMat, diag = TRUE),]
+    g.upper.tri = g[upper.tri(corMat, diag = TRUE),]
     corMat.upper.index <- g.upper.tri[-which(g.upper.tri[,1]==g.upper.tri[,2]),]
     for (i in 1:nrow(corMat.upper.index)) {
-      i.temp <- corMat.upper.index[i,1]
-      j.temp <- corMat.upper.index[i,2]
-      sym.index <- intersect(which(corMat.lower.index[,2]==i.temp), which(corMat.lower.index[,1]==j.temp))
-      corMat.star[i.temp, j.temp] <- corMat.star[corMat.lower.index[sym.index,1], corMat.lower.index[sym.index,2]]
+      i.temp = corMat.upper.index[i,1]
+      j.temp = corMat.upper.index[i,2]
+      sym.index = intersect(which(corMat.lower.index[,2] == i.temp), which(corMat.lower.index[,1] == j.temp))
+      corMat.star[i.temp, j.temp] = corMat.star[corMat.lower.index[sym.index,1], corMat.lower.index[sym.index,2]]
     }
   }
   if (verbose == TRUE) {
